@@ -5,7 +5,7 @@ from typing import List, Optional, Dict
 import requests
 from requests import Response
 
-from knowledge.base.entity import LANGUAGE_CODE_TAG, LanguageCode, TEXT_TAG
+from knowledge.base.entity import LOCALE_TAG, LanguageCode, TEXT_TAG
 from knowledge.base.ontology import OntologyClassReference
 from knowledge.nel.base import PersonalEntityLinkingProcessor, EntitySource, KnowledgeSource, \
     KnowledgeGraphEntity, EntityType
@@ -24,8 +24,8 @@ class WacomEntityLinkingEngine(PersonalEntityLinkingProcessor):
     service_url: str
         URL of the service
     """
-    SERVICE_ENDPOINT: str = 'graphdata/nel/text'
-    SERVICE_URL: str = 'https://semantic-ink-private.wacom.com'
+    SERVICE_ENDPOINT: str = 'graph/nel/text'
+    SERVICE_URL: str = 'https://stage-private-knowledge.wacom.com'
     LANGUAGES: List[LanguageCode] = [
         LanguageCode('de_DE'),
         LanguageCode('en_US'),
@@ -68,7 +68,7 @@ class WacomEntityLinkingEngine(PersonalEntityLinkingProcessor):
             CONTENT_TYPE_HEADER_FLAG: 'application/json'
         }
         payload: Dict[str, str] = {
-            LANGUAGE_CODE_TAG: language_code,
+            LOCALE_TAG: language_code,
             TEXT_TAG: text
         }
         response: Response = requests.post(url, headers=headers, json=payload, verify=self.verify_calls)
