@@ -5,6 +5,8 @@ from abc import ABC
 import requests
 from requests import Response
 
+from knowledge.services import USER_AGENT_STR
+
 
 class WacomServiceException(Exception):
     """Exception thrown if Wacom service fails."""
@@ -89,8 +91,9 @@ class WacomServiceAPIClient(RESTAPIClient):
         WacomServiceException
             Exception if service returns HTTP error code.
         """
-        url: str = f'{self.service_url}/graphdata/{WacomServiceAPIClient.USER_LOGIN_ENDPOINT}/'
+        url: str = f'{self.service_url}/graph/{WacomServiceAPIClient.USER_LOGIN_ENDPOINT}/'
         headers: dict = {
+            'User-Agent': USER_AGENT_STR,
             'x-tenant-api-key': tenant_key
         }
         payload: dict = {
