@@ -14,8 +14,8 @@ from knowledge.base.entity import LanguageCode, DATA_PROPERTIES_TAG, DATA_PROPER
     DESCRIPTIONS_TAG, RELATIONS_TAG, EntityStatus, Label, Description
 from knowledge.base.ontology import DataProperty, OntologyPropertyReference, ThingObject, OntologyClassReference, \
     ObjectProperty
+from knowledge.services import USER_AGENT_STR
 from knowledge.services.base import WacomServiceAPIClient, WacomServiceException
-
 # ------------------------------------------------- Constants ----------------------------------------------------------
 ACTIVATION_TAG: str = 'activation'
 SEARCH_TERM: str = 'searchTerm'
@@ -37,6 +37,8 @@ SUBJECT_URI: str = 'subjectUri'
 NEXT_PAGE_ID_TAG: str = 'nextPageId'
 TENANT_RIGHTS_TAG: str = 'tenantRights'
 RELATION_TAG: str = 'relation'
+USER_AGENT_TAG: str = "User-Agent"
+
 
 MIME_TYPE: Dict[str, str] = {
     '.jpg': 'image/jpeg',
@@ -83,7 +85,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
     service_endpoint: str
         Base endpoint
     """
-    PERSONAL_KNOWLEDGE_URL: str = 'https://semantic-ink-private.wacom.com'
+    PERSONAL_KNOWLEDGE_URL: str = 'https://stage-private-knowledge.wacom.com'
     USER_ENDPOINT: str = 'user'
     ENTITY_ENDPOINT: str = 'entity'
     ENTITY_IMAGE_ENDPOINT: str = 'entity/image/'
@@ -102,7 +104,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
     ONTOLOGY_UPDATE_ENDPOINT: str = 'ontology-update'
 
     def __init__(self, application_name: str, service_url: str = PERSONAL_KNOWLEDGE_URL,
-                 service_endpoint: str = 'graphdata'):
+                 service_endpoint: str = 'graph'):
         super().__init__(application_name, service_url, service_endpoint)
 
     def entity(self, auth_key: str, uri: str) -> ThingObject:
@@ -130,6 +132,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{WacomKnowledgeService.ENTITY_ENDPOINT}/{urllib.parse.quote(uri)}'
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         response: Response = requests.get(url, headers=headers, verify=self.verify_calls)
@@ -189,6 +192,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
             raise WacomServiceException("Please delete less than 100 entities.")
         url: str = f'{self.service_base_url}{WacomKnowledgeService.ENTITY_ENDPOINT}'
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         params: Dict[str, Any] = {
@@ -220,6 +224,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{WacomKnowledgeService.ENTITY_URI_ENDPOINT.format(urllib.parse.quote(uri))}'
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         response: Response = requests.delete(url, headers=headers, params={'forceDelete': force},
@@ -279,6 +284,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         literals: List[dict] = []
         # Header info
         headers: dict = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             'Content-Type': 'application/json',
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
@@ -334,6 +340,8 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         response: Response = requests.post(url, json=payload, headers=headers, verify=self.verify_calls)
         if response.ok:
             uri: str = response.json()[URI_TAG]
+            if entity.image is not None and entity.image != '':
+                self.set_entity_image_url(auth_key, uri, entity.image)
             return uri
 
         import json
@@ -370,6 +378,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         literals: List[dict] = []
         # Header info
         headers: dict = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             'Content-Type': 'application/json',
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
@@ -452,6 +461,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{WacomKnowledgeService.RELATIONS_ENDPOINT.format(urllib.parse.quote(uri))}'
         headers: dict = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         response: Response = requests.get(url, headers=headers, verify=self.verify_calls)
@@ -484,6 +494,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{WacomKnowledgeService.LABELS_ENDPOINT.format(urllib.parse.quote(uri))}'
         headers: dict = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         response: Response = requests.get(url, headers=headers, verify=self.verify_calls)
@@ -518,6 +529,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{WacomKnowledgeService.LITERAL_ENDPOINT.format(urllib.parse.quote(uri))}'
         headers: dict = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         response: Response = requests.get(url, headers=headers, verify=self.verify_calls)
@@ -549,6 +561,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         """
         url: str = f'{self.service_base_url}{WacomKnowledgeService.RELATION_ENDPOINT.format(source)}'
         headers: dict = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         params: dict = {
@@ -590,6 +603,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
             TARGET: target
         }
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         # Get response
@@ -627,6 +641,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         url: str = f'{self.service_url}/{self.service_endpoint}{WacomKnowledgeService.ACTIVATIONS_ENDPOINT}'
 
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         params: dict = {
@@ -682,6 +697,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         url: str = f'{self.service_url}/{self.service_endpoint}{WacomKnowledgeService.LISTING_ENDPOINT}'
         # Header with auth token
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         # Parameter with filtering and limit
@@ -732,6 +748,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         url: str = f'{self.service_base_url}{WacomKnowledgeService.ONTOLOGY_UPDATE_ENDPOINT}'
         # Header with auth token
         headers: dict = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG: f'Bearer {auth_key}'
         }
         response: Response = requests.patch(url, headers=headers, verify=self.verify_calls)
@@ -772,6 +789,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
             If the graph service returns an error code.
         """
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG:  f'Bearer {auth_key}'
         }
         parameters: Dict[str, Any] = {
@@ -819,6 +837,7 @@ class WacomKnowledgeService(WacomServiceAPIClient):
             If the graph service returns an error code.
         """
         headers: Dict[str, str] = {
+            USER_AGENT_TAG: USER_AGENT_STR,
             AUTHORIZATION_HEADER_FLAG:  f'Bearer {auth_key}'
         }
         parameters: Dict[str, Any] = {
@@ -1024,20 +1043,25 @@ class WacomKnowledgeService(WacomServiceAPIClient):
         WacomServiceException
             If the graph service returns an error code.
         """
-        response: Response = requests.get(image_url)
-        if response.ok:
-            image_bytes: bytes = response.content
-            file_name: str = image_url if file_name is None else file_name
-            if mime_type is None:
-                _, file_extension = os.path.splitext(file_name.lower())
-                if file_extension not in MIME_TYPE:
-                    raise WacomServiceException(f'Creation of entity image failed. Mime-type cannot be '
-                                                f'identified or is not supported.'
-                                                f'Response code:={response.status_code}, '
-                                                f'exception:= {response.content}')
-                mime_type = MIME_TYPE[file_extension]
+        with requests.session() as session:
+            headers: Dict[str, str] = {
+                USER_AGENT_TAG: f'ImageFetcher/0.1 (https://github.com/Wacom-Developer/personal-knowledge-library)'
+                              f' personal-knowledge-library/0.2.4'
+            }
+            response: Response = session.get(image_url, headers=headers)
+            if response.ok:
+                image_bytes: bytes = response.content
+                file_name: str = image_url if file_name is None else file_name
+                if mime_type is None:
+                    _, file_extension = os.path.splitext(file_name.lower())
+                    if file_extension not in MIME_TYPE:
+                        raise WacomServiceException(f'Creation of entity image failed. Mime-type cannot be '
+                                                    f'identified or is not supported.'
+                                                    f'Response code:={response.status_code}, '
+                                                    f'exception:= {response.content}')
+                    mime_type = MIME_TYPE[file_extension]
 
-            return self.set_entity_image(auth_key, entity_uri, image_bytes, file_name, mime_type)
+                return self.set_entity_image(auth_key, entity_uri, image_bytes, file_name, mime_type)
         if not response.ok:
             raise WacomServiceException(f'Creation of entity image failed'
                                         f'Response code:={response.status_code}, exception:= {response.content}')
