@@ -56,11 +56,11 @@ def ontology_import(rdf_content: str, tenant_id: str = '', context: str = '') ->
     # Parse object properties
     for object_property_iri in [s for s, p, o in rdf_graph.triples((None, RDF.type, OWL.ObjectProperty))]:
         subproperty_of: Optional[OntologyPropertyReference] = None
-        range_prop: Optional[OntologyClassReference] = None
+        obj_range_prop: Optional[OntologyClassReference] = None
         domain_prop: Optional[OntologyPropertyReference] = None
         inverse_prop: Optional[OntologyPropertyReference] = None
         for _, _, o in rdf_graph.triples((object_property_iri, RDFS.range, None)):
-            range_prop = OntologyClassReference.parse(o)
+            obj_range_prop = OntologyClassReference.parse(o)
         for _, _, o in rdf_graph.triples((object_property_iri, RDFS.domain, None)):
             domain_prop = OntologyClassReference.parse(o)
         for _, _, o in rdf_graph.triples((object_property_iri, OWL.inverseOf, None)):
@@ -70,6 +70,6 @@ def ontology_import(rdf_content: str, tenant_id: str = '', context: str = '') ->
         ontology.add_properties(OntologyProperty(kind=PropertyType.OBJECT_PROPERTY, tenant_id=tenant_id,
                                                  context=context,
                                                  name=OntologyPropertyReference.parse(object_property_iri),
-                                                 property_range=range_prop, property_domain=domain_prop,
+                                                 property_range=obj_range_prop, property_domain=domain_prop,
                                                  subproperty_of=subproperty_of, inverse_property_of=inverse_prop))
     return ontology
